Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetServerChain ¶
func SetServerChain(c *Chain)
SetServerChain sets the server chain object to package variable serverChain.
Types ¶
type Chain ¶
type Chain struct {
ID string
Version string
CreationDate time.Timestamp
BlockWorker string
SignatureScheme string
MinSubmit int
MinCfm int
}
Chain represents data structure that holds the chain data.
func GetServerChain ¶
func GetServerChain() *Chain
GetServerChain returns the chain object for the server chain.
type Config ¶
type Config interface {
// LogDir returns directory to store logs.
LogDir() string
// LogLvl returns level of logs.
LogLvl() string
// BlockWorker returns address of dns server.
BlockWorker() string
// SignatureScheme returns signature scheme.
SignatureScheme() string
}
Config represents config interface used for setup wallet.
Click to show internal directories.
Click to hide internal directories.