Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Balance ¶
Balance responds balance of the wallet that used.
NOTE: for using Balance you must set wallet info by running zcncore.SetWalletInfo.
func SetupZCNSDK ¶
SetupZCNSDK runs zcncore.SetLogFile, zcncore.SetLogLevel and zcncore.InitZCNSDK using provided Config.
If an error occurs during execution, the program terminates with code 2 and the error will be written in os.Stderr.
SetupZCNSDK should be used only once while application is starting.
Types ¶
type Config ¶
type Config interface {
// LogDir returns directory to store logs.
LogDir() string
// LogLvl returns level of logs.
LogLvl() string
// BlockWorker returns address of dns server.
BlockWorker() string
// SignatureScheme returns signature scheme.
SignatureScheme() string
}
Config represents config interface used for setup wallet.
type Wallet ¶
Wallet represents a wallet that stores keys and additional info.
func (*Wallet) ID ¶
ID returns the client id.
NOTE: client id represents hex encoded SHA3-256 hash of the raw public key.
func (*Wallet) RegisterToMiners ¶
RegisterToMiners registers wallet to the miners by executing zcncore.RegisterToMiners.
func (*Wallet) StringJSON ¶
StringJSON returns marshalled to JSON string Wallet.ZCNWallet.